// Copyright 2022 Jens W. Wulf, originally published at http://www.jwwulf.de/en/kbd/
// This file licensed under the
// Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License.
// To view a copy of this license, visit
// https://creativecommons.org/licenses/by-nc-sa/4.0/

// Print settings:
// 15% Gyroid Infill, unten zwei Layer, oben drei. Zwei Perimeter.
include <jw_rect_round.scad>

// (un)comment the mirror-statement in line 100 for left/right part.

// Abstand des Wellenmittelpunkts zur Ecke
dr=6;

// Rand in y-Richtung, also die Dicke des Materials bei den Löchern
ry1=13;
ry2=6;

// Durchmesser der Welle
dw=6+0.5; 

// mehr Platz um die Welle herum
dh=dw+2*3;

// Ausgaben der Grid-Erzeugung:
grid_dist_x=0.993421052631579;
grid_dist_y=1.005741980767742;
dx=75.5;
dy=62.3560028076;
// Und Berechnungen damit:
scaley = dy / (grid_dist_y * (dy/grid_dist_y - 1)) * grid_dist_y;
scalex = dx / (grid_dist_x * (dx/grid_dist_x - 1)) * grid_dist_x;
ly=dy;

 
module fast_alles() {
  difference(){
    translate([0,0,22])
      rotate([0,25,0])
        intersection(){
          union(){ 
            translate([dx,dy,18]) rotate([0,0,180]) scale([scalex, scaley, 1]) surface(file="ablage_rechts_2.grid");
            translate([0,0,-100-8]) cube([dx,dy,100],center=false);
          }
          translate([0,0,-50]) jw_rect_round(dx, dy, 100, 3, 20, center=false);
        }
    translate([0,0,-100]) cube([200,200,200],center=true);
    translate([-200,-1,-1]) cube([200,200,200],center=false);
      
    // unnötigen Überstand schneiden
    translate([0,20,20]) rotate([0,20,0]) rotate([0,0,-10]) translate([-20,0,0]) cube([40,200,100], center=true);
  }
}

module welle(alpha,alpha2){
  union() {
      // durchgehendes Loch für die Welle
      rotate([90,0,0]) cylinder(d=dw, h=200, $fn=30, center=true);
     
      // innere Aussparung um die Welle, muss zwingende vorhanden sein
      translate([0,ry1,0]) rotate([-90,0,0]) cylinder(d=dh, h=ly-ry1-ry2, $fn=60, center=false);
    
      // vergrößert die innere Aussparung, damit es leichter zu drucken ist
      //translate([dh/2/sqrt(2),ry1,dh/2/sqrt(2)]) rotate([0,-130,0]) cube([3*dh, ly-ry1-ry2, 3*dh],center=false);
      translate([dh/2/sqrt(2),ry1,dh/2/sqrt(2)]) rotate([0,-130,0])
        translate([0,0,3*dh]) rotate([0,90,0]) hull() {
          hc=20;
          jw_rect_round(3*dh, ly-ry1-ry2, hc, 6, 40, false);
          cube([3*dh, ly-ry1-ry2, 1],center=false);
      }
      
      // vergrößert die innere Aussparung, damit es leichter zu drucken ist
      translate([-dr-99-0.01,ry1,-dr]) cube([dr+99, ly-ry1-ry2, dr+dh/2],center=false);
      translate([-dr,ry1,-99-0.01-dr]) cube([dr+dh/2, ly-ry1-ry2, dr+99],center=false);
      
      
      // Rundung um Drehachse
      rotate([0,alpha,0]) translate([-0.01,-9,-0.01]) difference(){
        translate([-100,0,-100]) cube([100,100,100],center=false);
        rotate([90,0,0]) cylinder(d=2*dr, h=200, $fn=30, center=true);
      }
      
      rotate([0,alpha,0]) translate([-1,-9,-dr-0.01-100]) cube([100,100,100],center=false);
      
      // Unterlage mit kleiner Bauhöhe
      rotate([0,alpha,0]) translate([0,ry1,-100-dw/2]) cube([100,ly-ry1-ry2,100],center=false);
      
      rotate([0,alpha2,0]) translate([-100-dr,-9,0]) cube([100,100,100],center=false);
      
   }
}

if (0 > 0) {
  welle(15,4);
}
else { 

// (un)comment the following line for left/right part:
mirror([1,0,0])
  difference() {
    fast_alles();
        
    rotate([4,0,-5]) translate([dr,0,dr]) welle(15,3);
  }
}
