// Copyright 2022 Jens W. Wulf, originally published at http://www.jwwulf.de/en/kbd/
// This file licensed under the
// Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License.
// To view a copy of this license, visit
// https://creativecommons.org/licenses/by-nc-sa/4.0/

// Print settings:
// 15% Gyroid Infill, unten zwei Layer, oben zwei. Zwei Perimeter.
include <jw_rect_round.scad>
include <print_par.scad>

// (un)comment the mirror-statement in line 110  for left/right part.

// Abstand des Wellenmittelpunkts zur Ecke
dr=6;

// Rand in y-Richtung, also die Dicke des Materials bei den Löchern
ry1=13;
ry2=6;

// Durchmesser der Welle
dw=6+0.5; 

// mehr Platz um die Welle herum
dh=dw+2*3;

// Ausgaben der Grid-Erzeugung:
grid_dist_x=0.993421052631579;
grid_dist_y=1.005741980767742;
dx=75.5;
dy=62.3560028076;
// Und Berechnungen damit:
scaley = dy / (grid_dist_y * (dy/grid_dist_y - 1)) * grid_dist_y;
scalex = dx / (grid_dist_x * (dx/grid_dist_x - 1)) * grid_dist_x;
ly=dy;

dz = 8.5;

 
module welle(alpha,dicke, nachoben){

  xhs = 33;

  ym = ry1+(ly-ry1-ry2)/2;
  difference(){
    union() {
     
      // innere Aussparung um die Welle, muss zwingende vorhanden sein
      intersection(){
        translate([0,ry1,0]) rotate([-90,0,0]) cylinder(d=dw+2*2.5, h=ly-ry1-ry2, $fn=60, center=false);
        union(){
          rotate([0,alpha,0]) translate([-dh/2,ry1,     -dh/2]) cube([dh,4,dh],center=false);        
          rotate([0,alpha,0]) translate([-dh/2,ly-ry2-4,-dh/2]) cube([dh,4,dh],center=false);
        }
      }
                     
      // Unterlage mit kleiner Bauhöhe
      rotate([0,alpha,0]) hull() {
        //translate([-dh/2,ry1,-dicke-dw/2]) cube([70,ly-ry1-ry2,dicke+nachoben],center=false);
        translate([-dh/2,ry1,-dicke-dw/2]) jw_rect_round(70,ly-ry1-ry2,dicke+nachoben,3,30,false);
        translate([   -dh/2-10,ym,-dicke-dw/2]) cylinder(d=10,h=dicke,$fn=40);
        translate([ 70-dh/2+10,ym,-dicke-dw/2]) cylinder(d=10,h=dicke,$fn=40);
      }
      
      rotate([0,alpha,0]) translate([xhs, ym, -5]) rotate([0,-20,0]) cylinder(d=3+2*print_w3,h=8,$fn=30,center=false);
    } 
    
    // M3-Schrauben direkt ins Plastik als höhenverstellbare Füße:
    rotate([0,alpha,0]) translate([   -dh/2-10,ym,-dicke-dw/2]) cylinder(d=3,h=88,$fn=40,center=true);
    rotate([0,alpha,0]) translate([ 70-dh/2+10,ym,-dicke-dw/2]) cylinder(d=3,h=88,$fn=40,center=true);

    // Eine M3-Schraube direkt ins Plastik um den Winkel einzustellen:
    rotate([0,alpha,0]) translate([xhs, ym, -5]) rotate([0,-20,0]) cylinder(d=3,h=88,$fn=30,center=true);

    // durchgehendes Loch für die Welle
    rotate([90,0,0]) cylinder(d=dw, h=200, $fn=30, center=true);
  }
}

module verbindungsflaeche(alpha){
  d = 10;
  rotate([0,alpha,0])
    translate([-dh/2+40+30/2, 8+(ly-ry1-ry2+2)/2, -3-d-dh/2+dz+(3+d)/2]) cube([30,ly-ry1-ry2+2,3+d],center=true);
}

module verbindungsflaeche_negativ(alpha){
  d = 10;
  rotate([0,alpha,0]) union() {  
    translate([-dh/2+40+30/2, 8+(ly-ry1-ry2+2)/2, -3-d-dh/2+dz+(3+d)/2]) cylinder(d=4,h=88,$fn=30,center=true);
    translate([-dh/2+40+30/2, 8+(ly-ry1-ry2+2)/2, -5-2]) cylinder(d=11,h=10,$fn=30,center=true);
  }
}

/*
welle(0);
verbindungsflaeche(0);
*/

ein_winkel = 23;

mirror([1,0,0])
difference(){
  union(){
    rotate([4,0,-5]) translate([dr,0,dr]) welle(ein_winkel, 3, 0);
  
    intersection(){
      translate([dr,0,dr]) verbindungsflaeche(ein_winkel);
      rotate([4,0,-5]) translate([dr,0,dr]) welle(ein_winkel, 3, 10);
    }
  }
  translate([dr,0,dr]) verbindungsflaeche_negativ(ein_winkel);
}

